Class: Google::Cloud::Storage::File::Updater

Inherits:
File
  • Object
show all
Defined in:
lib/google/cloud/storage/file.rb

Overview

Yielded to a block to accumulate changes for a patch request.

Instance Method Summary collapse

Instance Method Details

#metadataHash(String => String)

A hash of custom, user-provided web-safe keys and arbitrary string values that will returned with requests for the file as "x-goog-meta-" response headers.

Returns:

  • (Hash(String => String))


2348
2349
2350
# File 'lib/google/cloud/storage/file.rb', line 2348

def 
  @metadata
end

#metadata=(metadata) ⇒ Object

Updates the hash of custom, user-provided web-safe keys and arbitrary string values that will returned with requests for the file as "x-goog-meta-" response headers.

Parameters:

  • metadata (Hash(String => String))

    The user-provided metadata, in key/value pairs.



2360
2361
2362
2363
2364
# File 'lib/google/cloud/storage/file.rb', line 2360

def metadata= 
  @metadata = 
  @gapi. = @metadata
  update_gapi! :metadata
end